import java.util.*;

// abstract checker

public class JohnChecker
{
    public static final int MINN = 1;
	public static final int MAXN = 100;
    public static final int MINM = 3;
	public static final int MAXM = 20;
	public static final int MINXY = 0;
	public static final int MAXXY = 1000;

    public static polygon [] polygons;
    public static point [] points = new point[MAXM*MAXM*MAXN];
    public static int npts = 0;

	public static void printError(int line, String msg)
	{
		System.out.println("ERROR Line " + line + ": " + msg);
		System.exit(-1);
	}

    public static void checkIntBounds(int x, int min, int max, String name, int nLines)
    {
        if (x < min || x > max)
            printError(nLines, "invalid " + name + " value: " + x);
    }

    public static boolean addPt(point p)
    {
        for(int i=0; i<npts; i++) {
            if (p.equals(points[i]))
                return false;
        }
        points[npts] = new point(p);
        npts++;
        return true;
    }

    public static boolean between(double a, double b, double c)
    {
        if (equals(b, c))
            return false;
        if (b < c)
            return (equals(a,b) || equals(a, c) || (b < a) && (a < c));
        else
            return (equals(a,b) || equals(a, c) || (c < a) && (a < b));
    }

	public static boolean equals(double a, double b)
    {
        return (Math.abs(a-b) < 0.000001);
    }

    public static boolean lineIntersect(segment s1, segment s2, Intersection pt)
    {
        pt.overlap = false;             // two segments overlap
        pt.endpoint = false;            // intersection point is an endpoint of both segments
        point p1 = s1.p1;
        point p2 = s1.p2;
        point p3 = s2.p1;
        point p4 = s2.p2;
        if (p1.equals(p3) || p1.equals(p4)) {
            pt.p.x = p1.x;
            pt.p.y = p1.y;
            pt.endpoint = true;
            return true;
        }
        if (p2.equals(p3) || p2.equals(p4)) {
            pt.p.x = p2.x;
            pt.p.y = p2.y;
            pt.endpoint = true;
            return true;
        }
        double x1 = p1.x;
        double y1 = p1.y;
        double x2 = p2.x;
        double y2 = p2.y;
        double x3 = p3.x;
        double y3 = p3.y;
        double x4 = p4.x;
        double y4 = p4.y;
        double dx1 = x2-x1;
        double dx2 = x4-x3;
        double dy1 = y2-y1;
        double dy2 = y4-y3;

        double denom = dy2*dx1-dy1*dx2;
        double dx3 = x1-x3;
        double dy3 = y1-y3;
        if (equals(denom, 0.0)) {                   // parallel
            if (!equals(dy3*dx1-dy1*dx3, 0))        // not colinear
                return false;
            if (between(x1, x3, x4) || between(x2, x3, x4) || between(x3, x1, x2)) {
                pt.overlap = true;
                return true;
            }
            if (between(y1, y3, y4) || between(y2, y3, y4) || between(y3, y1, y2)) {
                pt.overlap = true;
                return true;
            }
            return false;
        }
        double t = (dx2*dy3-dy2*dx3)/denom;
        double u = (dx1*dy3-dy1*dx3)/denom;
        if (!equals(t, 0.0) && t < 0.0)
            return false;
        if (!equals(t, 1.0) && t > 1.0)
            return false;
        if (!equals(u, 0.0) && u < 0.0)
            return false;
        if (!equals(u, 1.0) && u > 1.0)
            return false;
        pt.p.x = x1 + t*dx1;
        pt.p.y = y1 + t*dy1;
        return true;
    }

    public static void main(String [] args)
	{
		Scanner in = new Scanner(System.in);
		int n, x, y, nLines = 0;
		String line;
		Intersection pt = new Intersection();

        line = in.nextLine();
        nLines++;
        StringTokenizer st = new StringTokenizer(line);
        if (st.countTokens() != 1)
            printError(nLines, "number of values on line incorrect");
		n = Integer.parseInt(st.nextToken());
		checkIntBounds(n, MINN, MAXN, "n", nLines);
		polygons = new polygon[n];
		for(int i=0; i<n; i++) {
			line = in.nextLine();
			nLines++;
			st = new StringTokenizer(line);
			int m = Integer.parseInt(st.nextToken());
			checkIntBounds(m, MINM, MAXM, "m", nLines);
			if (st.countTokens() != 2*m)
				printError(nLines, "number of values on line incorrect");
            polygons[i] = new polygon();
            x = Integer.parseInt(st.nextToken());
            y = Integer.parseInt(st.nextToken());
            checkIntBounds(x, MINXY, MAXXY, "x", nLines);
            checkIntBounds(y, MINXY, MAXXY, "y", nLines);
            point p1 = new point(x, y);
            addPt(p1);
            point p2 = new point();
            for(int j=1; j<m; j++) {
                int xx = Integer.parseInt(st.nextToken());
                int yy = Integer.parseInt(st.nextToken());
                checkIntBounds(xx, MINXY, MAXXY, "x", nLines);
                checkIntBounds(yy, MINXY, MAXXY, "y", nLines);
                p2 = new point(xx, yy);
                segment s = new segment(p1,p2);
                for(int k=0; k<i; k++) {
                    for(int l=0; l<polygons[k].nsegs; l++) {
                        segment s2 = polygons[k].segs[l];
                        if (lineIntersect(s, s2, pt)) {
                            if (pt.overlap)
                                printError(nLines, "polygons " + i + " and " + k + " have overlapping edges");
                            if (!addPt(pt.p))
                                printError(nLines, "point " + pt.p.x + "," + pt.p.y + " touched by more than 2 segments");
                        }
                    }
                }
                polygons[i].add(s);
                if (!addPt(p2))
                    printError(nLines, "point " + p2.x + "," + p2.y + " touched by more than 2 segments");
                p1 = p2;
            }
            polygons[i].add(new segment(p1, new point(x, y)));
            if (!polygons[i].verifySimple())
                printError(nLines, "non-simple polygon");
		}
		if (in.hasNextLine())
			printError(nLines, "incorrect number of lines");
        System.exit(42);
	}
}

class point {
	public double x, y;

	public point()
	{
        x = 0.0;
        y = 0.0;
    }

	public point(double xx, double yy)
	{
        x = xx;
        y = yy;
    }

    public point(point p)
    {
        x = p.x;
        y = p.y;
    }

	public boolean equals(point rhs)
	{
		return (JohnChecker.equals(x, rhs.x) && JohnChecker.equals(y, rhs.y));
	}

	public String toString()
	{
	    return "(" + x+","+y+")";
	}
}

class segment {
	public point p1, p2;

	public segment()
	{
        p1 = new point();
        p2 = new point();
    }

	public segment(point pp1, point pp2)
	{
        p1 = new point(pp1);
        p2 = new point(pp2);
    }

    public String toString()
    {
        return p1 + "," + p2;
    }
}

class polygon {

	public segment [] segs = new segment[20];
	public int nsegs;

	public void add(segment s)
	{
	    segs[nsegs] = new segment(s.p1, s.p2);
		nsegs++;
	}

	public boolean verifySimple()
	{
	    Intersection pt = new Intersection();
	    for(int i=0; i<nsegs; i++) {
            for(int j=i+1; j<nsegs; j++) {
                boolean intersect = JohnChecker.lineIntersect(segs[i], segs[j], pt);
                if (intersect) {
                    if (!pt.endpoint)
                        return false;
                    else if (!(j == i+1 || (i==0 && j==nsegs-1)))
                        return false;
                }
            }
	    }
	    return true;
	}

    public void print()
    {
        for(int i=0; i<nsegs; i++) {
            System.out.println("(" + segs[i].p1.x + "," + segs[i].p1.y + ")-(" + segs[i].p2.x + "," + segs[i].p2.y + ")");
        }
    }
}

class Intersection
{
    public point p = new point();
    public boolean endpoint, overlap;
};
